##  Add Initiatives
Create Initiatives to illustrate the overall transformation plan. These Initiatives can be further detailed in later steps, but it's important to establish an overview of the major parts of the transformation.
When completing your Initiative Fact Sheets, ensure that you define a set of [mandatory attributes](https://help.sap.com/docs/leanix/ea/mandatory-attributes?locale=en-US&state=PRODUCTION&version=CLOUD "Mandatory attributes are essential fields specified by admins to ensure data integrity and quality in fact sheets. They must be filled out for fact sheets to approve quality seal, ensuring consistent and reliable information."). They should be added to your Initiative Fact Sheet or Fact Sheet subtypes. These may include Lifecycle Data, Milestones (possible once the SAP LeanIX Architecture and Road Map Planning is activated), subscriptions, and relations to Application and Objective Fact Sheets, among any other relevant information for your organization.
